%define mod_name mod_auth_openidc
%define mod_conf auth_openidc.conf
%define mod_so %{mod_name}.so

Name:             apache-%{mod_name}
Version:          2.4.13.2
%define subrel 2
Release:          %mkrel 1
Summary:          OpenID Connect Relying Party and OAuth 2.0 Resource Server for Apache HTTP Server 2.x
Group:            System/Servers
License:          Apache License
URL:              https://github.com/pingidentity/mod_auth_openidc
Source:           https://github.com/pingidentity/mod_auth_openidc/archive/v%{version}/%{mod_name}-%{version}.tar.gz
Patch0:           CVE-2024-24814.patch
Patch1:           0004-Fix-CVE-2025-31492-protected-content-leakage-when-us.patch
BuildRequires:    apache-devel
BuildRequires:    pkgconfig(libcurl)
BuildRequires:    pkgconfig(jansson) >= 2.0
BuildRequires:    pkgconfig(libpcre2-8)
BuildRequires:    pkgconfig(cjose) >= 0.5.1

Requires:         apache

%description
mod_auth_openidc is an authentication/authorization module for the
Apache 2.x HTTP server that authenticates users against an
OpenID Connect Provider. It can also function as an OAuth 2.0 Resource Server,
validating access tokens presented by OAuth 2.0 clients against an OAuth 2.0
Authorization Server.

%prep
%setup -q -n %{mod_name}-%{version}
%autopatch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build

%install
install -d %{buildroot}%{_httpd_moddir}
install -d %{buildroot}%{_sysconfdir}/httpd/conf/conf.d
install -d %{buildroot}%{_sysconfdir}/httpd/conf/modules.d

%make_install MODULES_DIR=%{buildroot}%{_httpd_moddir}

cat << EOF > 10_%{mod_conf}
LoadModule auth_openidc_module modules/mod_auth_openidc.so
EOF

install -m0644 %{mod_conf} %{buildroot}%{_sysconfdir}/httpd/conf/conf.d/
install -m0644 10_%{mod_conf} %{buildroot}%{_sysconfdir}/httpd/conf/modules.d/

%files
%doc AUTHORS ChangeLog INSTALL LICENSE.txt README.md
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/httpd/conf/conf.d/%{mod_conf}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/httpd/conf/modules.d/10_%{mod_conf}
%attr(0755,root,root) %{_httpd_moddir}/%{mod_name}.so


%changelog
* Tue Apr 29 2025 ns80 <ns80> 2.4.13.2-1.2.mga9
+ Revision: 2179897
- add patch from Debian for CVE-2025-31492 (mga#34216)
- port a patch from Debian for CVE-2024-24814 (mga#32928)

* Mon Apr 17 2023 ns80 <ns80> 2.4.13.2-1.mga9
+ Revision: 1953455
- new version 2.4.13.2 for CVE-2023-28625 (mga#31331)

* Thu Apr 13 2023 daviddavid <daviddavid> 2.4.12.2-2.mga9
+ Revision: 1952891
- switch to pcre2 (mga#31791)

* Wed Dec 28 2022 ns80 <ns80> 2.4.12.2-1.mga9
+ Revision: 1927379
- new version 2.4.12.2 for CVE-2022-23527 (mga#31331)

* Sat Apr 02 2022 umeabot <umeabot> 2.4.9.4-3.mga9
+ Revision: 1840774
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.4.9.4-2.mga9
+ Revision: 1747819
- rebuild for openssl 3.0.0

* Thu Sep 09 2021 ns80 <ns80> 2.4.9.4-1.mga9
+ Revision: 1744585
- new version 2.4.9.4 for CVE-2021-32786 and CVE-2021-3279[12] (mga#29344)

* Mon Jun 14 2021 ns80 <ns80> 2.4.2.1-2.mga9
+ Revision: 1730666
- backport upsteam patch for CVE-2021-20718 (mga#29103)

* Tue Mar 31 2020 joequant <joequant> 2.4.2.1-1.mga8
+ Revision: 1562500
- update to 2.4.2.1

* Tue Mar 03 2020 ns80 <ns80> 2.3.2-5.mga8
+ Revision: 1553396
- add upstream patch for CVE-2019-20479 (mga#26289)
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Dec 12 2019 ns80 <ns80> 2.3.2-3.mga8
+ Revision: 1465978
- add patch for CVE-2019-14857 (mga#25810)

* Fri Sep 21 2018 umeabot <umeabot> 2.3.2-2.mga7
+ Revision: 1294384
- Mageia 7 Mass Rebuild

* Sun Nov 05 2017 mitya <mitya> 2.3.2-1.mga7
+ Revision: 1176000
- New version 2.3.2

* Sat Sep 09 2017 cjw <cjw> 2.2.0-2.mga7
+ Revision: 1152185
- rebuild for openssl 1.1

* Sat May 20 2017 mitya <mitya> 2.2.0-1.mga6
+ Revision: 1103480
- New version 2.2.0

* Sun Mar 12 2017 mitya <mitya> 2.1.6-1.mga6
+ Revision: 1092232
- New version 2.1.6

* Wed Feb 15 2017 mitya <mitya> 2.1.5-1.mga6
+ Revision: 1086337
- New version 2.1.5

* Thu Jan 12 2017 mitya <mitya> 2.1.3-1.mga6
+ Revision: 1081213
- New version 2.1.3

* Wed Dec 07 2016 mitya <mitya> 2.1.2-1.mga6
+ Revision: 1072944
- New release 2.1.2

* Sat Nov 12 2016 mitya <mitya> 2.1.1-1.mga6
+ Revision: 1066631
- New version 2.1.1

* Fri Sep 23 2016 daviddavid <daviddavid> 2.0.0-3.mga6
+ Revision: 1055545
- rebuild again for ARM as cjose is now available
- use a named-versioned tarball from github
- pass NOCONFIGURE=1 to autogen
+ neoclust <neoclust>
- Rebuild for arm

* Wed Sep 14 2016 mitya <mitya> 2.0.0-1.mga6
+ Revision: 1052582
- mod_auth_openidc 2.0.0
- Created package structure for apache-mod_auth_openidc.

